projects

# XMLRésuméLibrary: User Guide

project | Element Reference | province

## Name

projects — Container for one or more projects

## Synopsis

### Content Model

    (project+)

### Attributes

Name | Type | Default
--- | --- | ---
targets | CDATA | None

## Description

The `projects` element groups together one or more `project` elements.

### Parents

`projects` may be contained in these elements: `degree`, `job`

## See Also

`achievements`.

## Examples

    <projects>
      <project>Organization of Paperclips</project>
      <project>Development of rocket booster fuel</project>
      <project>1997 Papercut Convention</project>
    </projects>

project | Element Reference | province